@@ -194,6 +194,9 @@ class IMAPRepository(BaseRepository):
 
         return self.getconfint('remoteport', None)
 
+    def getipv6(self):
+        return self.getconfboolean('ipv6', None)
+
     def getssl(self):
         return self.getconfboolean('ssl', 1)
 
@@ -276,6 +279,9 @@ class IMAPRepository(BaseRepository):
     def getoauth2_refresh_token(self):
         return self.getconf('oauth2_refresh_token', None)
 
+    def getoauth2_access_token(self):
+        return self.getconf('oauth2_access_token', None)
+
     def getoauth2_client_id(self):
         return self.getconf('oauth2_client_id', None)
 
